@@ -79,7 +79,7 @@ class HubModel(abc.ABC):
         self.container = self.docker_client.containers.run(self.image_uri(), command, ports=ports, detach=True)
         time.sleep(1)
         try:
-            loop = asyncio.get_running_loop()
+            loop = asyncio.get_event_loop()
             self.logger_loop = loop.create_task(self.get_container_logs())
         except RuntimeError:
             # asyncio.run(self.get_container_logs())
